@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: caps.c,v 1.16 2002/10/15 01:49:25 nalin Exp $"
+#ident "$Id: caps.c,v 1.18 2002/12/10 00:08:32 nalin Exp $"
 #include "../config.h"
 #include <stdlib.h>
 #include <glib.h>
@@ -376,6 +376,9 @@ struct _vte_capability_string _vte_xterm_capability_strings[] = {
 	{ESC "#6", "double-width", 0},
 	{ESC "#8", "screen-alignment-test", 0},
 
+	/* These are actually designate-other-coding-system from ECMA 35,
+	 * but we don't support the full repertoire.  Actually, we don't
+	 * know what the full repertoire looks like. */
 	{ESC "%%@", "iso8859-1-character-set", 0},
 	{ESC "%%G", "utf-8-character-set", 0},
 
@@ -510,6 +513,7 @@ struct _vte_capability_string _vte_xterm_capability_strings[] = {
 	{CSI "%m'{", "select-locator-events", 0},
 	{CSI "%d'|", "request-locator-position", 0},
 
+	{OSC ";%s" BEL, "set-icon-and-window-title", 0}, /* undocumented default */
 	{OSC "0;%s" BEL, "set-icon-and-window-title", 0},
 	{OSC "1;%s" BEL, "set-icon-title", 0},
 	{OSC "2;%s" BEL, "set-window-title", 0},
