@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: debug.c,v 1.11 2002/11/25 20:39:19 nalin Exp $"
+#ident "$Id: debug.c,v 1.12 2002/12/10 22:36:29 nalin Exp $"
 #include "../config.h"
 #include <glib.h>
 #include "debug.h"
@@ -70,6 +70,9 @@ _vte_debug_parse_string(const char *string)
 			} else
 			if (g_ascii_strcasecmp(flags[i], "KEYBOARD") == 0) {
 				_vte_debug_flags |= VTE_DEBUG_KEYBOARD;
+			} else
+			if (g_ascii_strcasecmp(flags[i], "LIFECYCLE") == 0) {
+				_vte_debug_flags |= VTE_DEBUG_LIFECYCLE;
 			}
 		}
 		g_strfreev(flags);
