@@ -19,7 +19,7 @@
 #ifndef vte_vte_h_included
 #define vte_vte_h_included
 
-#ident "$Id: vte.h,v 1.57 2002/11/07 22:52:56 nalin Exp $"
+#ident "$Id: vte.h,v 1.58 2002/12/10 00:08:32 nalin Exp $"
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -107,7 +107,7 @@ typedef enum {
 struct vte_char_attributes {
 	long row, column;
 	GdkColor fore, back;
-	gboolean underline:1, alternate:1, strikethrough:1;
+	gboolean underline:1, strikethrough:1;
 };
 
 /* The widget's type. */
